@@ -1,7 +1,9 @@
 package Reddit::Client;
 
-our $VERSION = '1.28';
+our $VERSION = '1.281';
 # TODO: make ispost, iscomment and get_type static
+# 1.281 -morecomments get_collapsed args
+# 1.281 -get_collapsed can also return morecomments
 # 1.28  -get_links_by_id
 #		-get_collapsed_comments
 #		-get_comments new version
@@ -1237,7 +1239,6 @@ sub get_comments {
 	my $link_id	= $result->[0]{data}{children}[0]{data}{name};
 	# result->[0] is a listing with 1 element, the link, even if you requested a cmt
     my $comments = $result->[1]{data}{children};
-	#return $result;
 
 	my $return = [];
 	for my $cmt (@$comments) {
@@ -1280,9 +1281,19 @@ sub get_collapsed_comments {
 		api		=> API_MORECHILDREN,
 		data	=> $data,
 	);
-	#return $result;
 	my $comments = $result->{data}->{things};
-    return [ map { Reddit::Client::Comment->new($self, $_->{data}) } @$comments ];
+
+	my $return = [];
+	for my $cmt (@$comments) {
+		if ($cmt->{kind} eq 't1') {
+			push @$return, Reddit::Client::Comment->new($self, $cmt->{data});
+		} elsif ($cmt->{kind} eq 'more') {
+			my $more = Reddit::Client::MoreComments->new($self, $cmt->{data});
+			$more->{link_id} = $link_id;
+			push @$return, $more;
+		}
+	}
+	return $return;
 }
 
 sub submit_comment {
