@@ -11,13 +11,13 @@ use fields qw/link_flair_text media url link_flair_css_class num_reports
               created_utc banned_by subreddit title author_flair_text is_self
               author media_embed author_flair_css_class selftext domain
               num_comments clicked saved thumbnail subreddit_id approved_by
-              selftext_html created hidden over_18 permalink
+              selftext_html created hidden over_18 permalink morecomments
 		user_reports mod_reports/;
 
 use constant type => "t3";
 
 sub reply {
-    	my ($self, $text) = @_;
+    my ($self, $text) = @_;
 	$text || croak "need comment text";	
 	my $cmtid = $self->{session}->submit_comment(parent_id=>$self->{name}, text=>$text);
 	return "t1_".$cmtid if $cmtid;
@@ -32,21 +32,17 @@ sub spam {
 	return $self->{session}->spam($self->{name});
 }
 sub edit {
-    	my ($self, $text) = @_;
+    my ($self, $text) = @_;
 	croak 'This is not a self post' unless $self->{is_self};
 	my $post = $self->{session}->edit($self->{name}, $text);
 	$self->{selftext} = $text if $post;
 	return $post;
 }
 sub delete {
-    	my $self = shift;
+  	my $self = shift;
 	my $cmtid = $self->{session}->delete($self->{name});
 	return $cmtid;
 }
-sub comments {
-    my $self = shift;
-    return $self->{session}->get_comments(permalink => $self->{permalink});
-}
 
 sub hide {
     my $self = shift;
@@ -58,17 +54,22 @@ sub unhide {
     $self->{session}->unhide($self->{name});
 }
 
-# The API return a 'permalink' that starts at '/r/sub..'
-# This just prepends the rest of the address
-sub get_permalink {
+sub get_permalink { # deprecated
 	my $self = shift;
-	return "https://www.reddit.com$self->{permalink}";
+	return $self->{session}->get_origin().$self->{permalink};
+}
+sub get_web_url {
+	my $self = shift;
+	return $self->{session}->get_origin().$self->{permalink};
 }
 
-sub wtf {
+sub comments { # deprecated. Only existed briefly.
+    my $self = shift;
+    return $self->get_comments();
+}
+sub get_comments {
 	my $self = shift;
-	return "etf";
-
+	return $self->{session}->get_comments(permalink=>$self->{permalink});
 }
 
 1;
